==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/defaultconnection.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>ConnectionOptionsWidgetClass</name>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Use legacy SSL connection</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>DefaultConnection</name>
    <message>
        <source>Disconnection timed out</source>
        <translation>Verbindungsabbruch abgelaufen</translation>
    </message>
</context>
<context>
    <name>DefaultConnectionPlugin</name>
    <message>
        <source>Allows to set a standard TCP connection to Jabber server</source>
        <translation>Erlaubt das Setzen einer Standard TCP Verbindung zum Jabberserver</translation>
    </message>
    <message>
        <source>Default Connection</source>
        <translation></translation>
    </message>
    <message>
        <source>Organization: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Subunit: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Country: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Locality: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>State/Province: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Common Name: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Issuer Organization: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Issuer Unit Name: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Issuer Country: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Issuer Locality: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Issuer State/Province: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Issuer Common Name: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>SSL Authentication Error</source>
        <translation></translation>
    </message>
    <message>
        <source>Unable to validate the connection to %1 due to errors:</source>
        <translation></translation>
    </message>
    <message>
        <source>Connect</source>
        <translation></translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation></translation>
    </message>
    <message>
        <source>Trust this certificate</source>
        <translation></translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/de/defaultconnection.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>ConnectionOptionsWidgetClass</name>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Use legacy SSL connection</source>
        <translation>Benutze alte SSL Verbindung</translation>
    </message>
</context>
<context>
    <name>DefaultConnectionPlugin</name>
    <message>
        <source>Allows to set a standard TCP connection to Jabber server</source>
        <translation>Erlaubt den Aufbau von Standard TCP Verbindung zum Jabber-Server</translation>
    </message>
    <message>
        <source>Default Connection</source>
        <translation>Standardverbindung</translation>
    </message>
    <message>
        <source>Organization: %1</source>
        <translation>Organisation: %1</translation>
    </message>
    <message>
        <source>Subunit: %1</source>
        <translation>Abteilung: %1</translation>
    </message>
    <message>
        <source>Country: %1</source>
        <translation>Land: %1</translation>
    </message>
    <message>
        <source>Locality: %1</source>
        <translation>Ort: %1</translation>
    </message>
    <message>
        <source>State/Province: %1</source>
        <translation>Bundesland: %1</translation>
    </message>
    <message>
        <source>Common Name: %1</source>
        <translation>Bezeichnung: %1</translation>
    </message>
    <message>
        <source>Issuer Organization: %1</source>
        <translation>Herausgeber Organisation: %1</translation>
    </message>
    <message>
        <source>Issuer Unit Name: %1</source>
        <translation>Herausgeber Abteilung: %1</translation>
    </message>
    <message>
        <source>Issuer Country: %1</source>
        <translation>Herausgeber Land: %1</translation>
    </message>
    <message>
        <source>Issuer Locality: %1</source>
        <translation>Herausgeber Ort: %1</translation>
    </message>
    <message>
        <source>Issuer State/Province: %1</source>
        <translation>Herausgeber Bundesland: %1</translation>
    </message>
    <message>
        <source>Issuer Common Name: %1</source>
        <translation>Herausgeber Bezeichnung: %1</translation>
    </message>
    <message>
        <source>SSL Authentication Error</source>
        <translation>SSL Authentifizierungsfehler</translation>
    </message>
    <message>
        <source>Unable to validate the connection to %1 due to errors:</source>
        <translation>Kann Verbindung zu %1 Aufgrund von Fehlern nicht bestätigen:</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Trennen</translation>
    </message>
    <message>
        <source>Trust this certificate</source>
        <translation>Zertifikat akzeptieren</translation>
    </message>
</context>
</TS>
